# Example adapted from Chris Strelioff
from numpy import argsort
import lda.datasets

# Get some actual document data
# This is a two dimensional table of documents in each row, word frequencies in each column
reuters_data = lda.datasets.load_reuters()

# Get a list of document titles to help interpret results - corresponds to each row in the table
reuters_titles = lda.datasets.load_reuters_titles()

# Get the vocabulary in the documents - corresponds to each column in the table
reuters_vocab = lda.datasets.load_reuters_vocab()

print("We are classifying " + str(len(reuters_titles)) + " documents")
print("with " + str(len(reuters_vocab)) + " distinct words.")

print("For example the title of document 5 is: " + reuters_titles[5])

print("Word 4 is: " + reuters_vocab[4])
print("Its frequency in document 5 is: " + str(reuters_data[5][4]))


lda_model = lda.LDA(n_topics=20, n_iter=500)
lda_model.fit(reuters_data)

topic_word_mapping = lda_model.topic_word_

# Let's check the probability of 'mother' (word 4) in topic 3
# Notice that numpy n-dimensional arrays use commas between dimensions
print("The probability of word 4 in topic 3 is:")
print(topic_word_mapping[3,4])

# Checking the top words for each topic:
print("\nThe top 5 words in each topic:\n" + "="*50)
for topic in topic_word_mapping:
    # Get list of words for this topic from the mapping, sorted by descending probability
    words_in_topic = []
    sorted_indices = list(argsort(topic))[::-1]  # Get order of indices if this array were sorted
    for i in range(10):  # Get top 5
        index = sorted_indices[i]
        words_in_topic.append(reuters_vocab[index])
    print(", ".join(words_in_topic))

# Check the top topic for each document
doc_topic_mapping = lda_model.doc_topic_

print("\nBest topic for 10 documents:\n")
# Let's see if the first 10 cluster nicely
for n in range(10):
    best_topic = doc_topic_mapping[n].argmax()  # argmax returns the column with the maxmimum value for this row
    print("doc" + str(n) + ", titled: " + reuters_titles[n])
    print("Best topic: " + str(best_topic))

import matplotlib.pyplot as pplt

figure_container, my_plot_axes = pplt.subplots(2, 1)  # Make two rows, one column of plots

# Fill the subplots with each of the following two topics
my_plot_axes[0].stem(topic_word_mapping[4,:])
my_plot_axes[1].stem(topic_word_mapping[15,:])

pplt.show()
